%FIG3_3D(PAR, MODEL, T) Creates figure 3 of the main manuscript (in 3D)
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig3_3D(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % model with no diffusion, no FB, no receptor dynamics
    par1 = setpar_scenario(par, Ip, 'rec_off');
    res1 = spacialwnt_simulation(T, par1, model);

    % model with no diffusion, no FB, but with receptor dynamics
    par2 = setpar_scenario(par, Ip, 'fb_off');
    res2 = spacialwnt_simulation(T, par2, model);

    % model with weak FB but no diffusion (10 times weaker than reference)
    par4 = setpar_scenario(par, Ip, 'diff_off');
    par3 = setpar(par4, 'c_mRNA', par4(Ip.c_mRNA)/10, Ip);
    res3 = spacialwnt_simulation(T, par3, model);

    % model with strong FB but no diffusion
    % par4 defined above
    res4 = spacialwnt_simulation(T, par4, model);

    % model with diffusion
    par5 = par;
    res5 = spacialwnt_simulation(T, par5, model);

    % model with very strong diffusion (50 times stronger than reference)
    par6 = setpar(par, 'D_diff', 50*par(Ip.D_diff), Ip);
    res6 = spacialwnt_simulation(T, par6, model);
    
    mRNA1 = res1.states.mRNA;
    mRNA2 = res2.states.mRNA;
    mRNA3 = res3.states.mRNA;
    mRNA4 = res4.states.mRNA;
    mRNA5 = res5.states.mRNA;
    mRNA6 = res6.states.mRNA;

    fact_readout_dkk = 100; %proportionality factor between readout mRNA and dkk mRNA

    %% Figure
    figure()
    
    mRNA = [mRNA1; mRNA2; mRNA3; mRNA4; mRNA5; mRNA6]/fact_readout_dkk;
    
    cmap = [51, 51, 51
             0, 51,153
            51,102,153
            51,153,204
           102,153,204
           204,204,204]/255;

    colormap(cmap)
    
    H = bar3(mRNA');%,'b');
    ylim([0.5 21.5])
    xlim([0.5 6.5])
    zlim([0 max(mRNA(:))])

    light('Position',[35 5 +11])

    Hx=get(H(1),'parent');
    Hty=get(Hx,'ylabel');
    set(Hty,'string','Model setup');
    set(Hx,'Ytick',[1.5 20.5],'YtickLabel',{'PC','PP'})
    set(Hx,'XtickLabel',{'B','C','D','E','F','G'})

end

