%FIG5(PAR, MODEL, T) Creates figure 5 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig5(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % Wild-type conditions
    par1 = par;
    res1 = spacialwnt_simulation(T, par1, model);
    mRNA_refWT = res1.states.mRNA;
    dkk_refWT = res1.states.dkk;
    
    % Mutant condition (10 fold decr. of bcat degrad. at pos. 11)
    par2 = par;
    par2(Ip.apc_tot(11)) = par2(Ip.apc_tot(11))/10;
    res2 = spacialwnt_simulation(T, par2, model);
    mRNA_refMUT = res2.states.mRNA;
    dkk_refMUT = res2.states.dkk;
    
    %% Figure preparations
    fact_readout_dkk = 100; %proportionality factor between readout mRNA and dkk mRNA

    ymax = max([mRNA_refWT mRNA_refMUT])/fact_readout_dkk;

    scale_factor = 40;

    %% Figure
    figure()

    subplot(3,2,1)
    bar(1:21,mRNA_refWT/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 1.05*ymax])
    set(gca,'Xtick',[])
    title('TG mRNA (wild-type condition)')

    subplot(3,2,3)
    bar(1:21,mRNA_refMUT/fact_readout_dkk,'b')
    xlim([0.5 21.5])
    ylim([0 1.05*ymax])
    set(gca,'Xtick',[])
    title('TG mRNA (mutant condition)')

    subplot(3,2,5)
    changeMUT = 100*(mRNA_refMUT-mRNA_refWT)./mRNA_refWT;
    change_disp = changeMUT;
    change_disp(11)=change_disp(11)/scale_factor;
    bar(1:21,change_disp,'k')
    xlim([0.5 21.5])
    ylim([-20 20])
    set(gca,'Xtick',[1.5 20.5])
    set(gca,'XtickLabel',{'PC','PP'})
    title('Mutant-induced change of TG mRNA (in %)')

    subplot(3,2,2)
    bar(1:21,dkk_refWT,'b')
    xlim([0.5 21.5])
    set(gca,'Xtick',[])
    title('Free Dkk (wild-type condition)')

    subplot(3,2,4)
    bar(1:21,dkk_refMUT,'b')
    xlim([0.5 21.5])
    set(gca,'Xtick',[])
    title('Free Dkk (mutant condition)')

    subplot(3,2,6)
    %horizontal bars: average Dkk WT vs MUT
    barh([mean(dkk_refMUT) mean(dkk_refWT)],'r')
    set(gca,'YtickLabel',{'MUT','WT'})
    title('Average Dkk')

end

