%FIG6(PAR, MODEL, T) Creates figure 6 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig6(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % Wild-type conditions
    par1 = par;
    resWT = spacialwnt_simulation(T, par1, model);
    mRNA_WT = resWT.states.mRNA;
    
    % initialise vectors
    mRNA = cell(19,1);
    FC_vec = zeros(size(mRNA));

    for k=1:19
        %Mutant condition (10 fold decr. of bcat degrad. at pos. k+1, readout at k)
        par_a = par;
        par_a(Ip.apc_tot(k+1)) = par(Ip.apc_tot(k+1))/10;
        res_a = spacialwnt_simulation(T, par_a, model);
        mRNA{k} = res_a.states.mRNA;
        FC_vec(k) = (mRNA{k}(k)-mRNA_WT(k))/mRNA_WT(k);
    end

    %% Figure
    figure()

    plot(2:20,100*FC_vec,'o','LineWidth',5,'MarkerSize',6)
    xlabel('Position of mutant')
%    ylabel('TG expr. (neighbour)')
    ylim([-30 0])
    set(gca,'Ytick',-30:5:0)

end

