%FIG7(PAR, MODEL, T) Creates figure 7 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig7(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    % Wild-type conditions
    par1 = par;
    resWT = spacialwnt_simulation(T, par1, model);
    mRNA_WT = resWT.states.mRNA;

    kdeg_vec = [0 0.05 0.1:0.1:1] * par(Ip.apc_tot(11));
    effect = zeros(size(kdeg_vec));
    bcat = zeros(size(kdeg_vec));
    mRNA = cell(size(kdeg_vec));
    dkk = zeros(size(kdeg_vec));
    
    for k = 1:length(kdeg_vec)
        par_bc = par;
        par_bc(Ip.apc_tot(11)) = kdeg_vec(k);
        res_bc = spacialwnt_simulation(T, par_bc, model);
        mRNA{k} = res_bc.states.mRNA;
        effect(k) = mRNA{k}(12)/mRNA_WT(12)-1;
        bcat(k) = res_bc.states.bcat(11);
        dkk(k) = res_bc.states.dkk(11);
    end

    
    %% Figure
    figure()

    str = sprintf('APC-dependent beta-catenin \ndegradation rate constant');
    
    subplot(1,3,1)
    xplot = kdeg_vec * par(Ip.k3) / par(Ip.apc_tot(11));
    plot(xplot,100*effect,'LineWidth',2)
    xlim([0 1.05*max(xplot)])
    ylim([-30 0])
    set(gca,'Ytick',-30:5:0)
    xlabel(str)
    ylabel('Change in TG expr. (PP neighbour)')

    subplot(1,3,2)
    plot(xplot,bcat,'LineWidth',2)
    hold on
    b_max = (0.423/2.57e-4); %maximum beta-catenin level
    plot(xplot,ones(size(xplot))*b_max,'--')
    xlim([0 1.05*max(xplot)])
    ylim([0 1.05*b_max])
    xlabel(str)
    ylabel('beta-catenin level in mutant cell')

    subplot(1,3,3)
    plot(xplot,dkk,'LineWidth',2)
    xlim([0 1.05*max(xplot)])
    ylim([0 1.05*max(dkk)])
    xlabel(str)
    ylabel('Extracellular Dkk concentration in mutant cell')
    
end

