%FIG8(PAR, MODEL, T) Creates figure 8 of the main manuscript
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = fig8(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    
    D_diff = [1e-6 3e-6 1e-5 3e-5 1e-4 3e-4 1e-3 3e-3 1e-2 3e-2 0.1 0.3 1];

    % initialise vectors
    n = length(D_diff);
    mRNA_wt = zeros(n,1);
    dkk_wt = zeros(n,1);
    mRNA_mut = zeros(n,1);
    dkk_mut = zeros(n,1);
    
    %for 8A
    for k=1:n
        par_a = par;
        par_a(Ip.D_diff) = D_diff(k); %par(Ip.D_diff);
        
        % wild-type readout
        res_wt = spacialwnt_simulation(T, par_a, model);
        mRNA_wt(k) = res_wt.states.mRNA(12);
        dkk_wt(k) =  res_wt.states.dkk(12);
        
        par_a(Ip.apc_tot(11)) =  par_a(Ip.apc_tot(11))/10;
        
        % mutant readout
        res_mut = spacialwnt_simulation(T, par_a, model);
        mRNA_mut(k) = res_mut.states.mRNA(12);
        dkk_mut(k) = res_mut.states.dkk(12);        
    end
    
    %rel change in mRNA of neighbouring cell
    relMRNA = 100*(mRNA_mut./mRNA_wt-1);  
    
    %for 8B
    d_4plots = [1e-4 1/1500 1/150 1/3];
    changeMUT = cell(size(d_4plots));
    for k=1:4
        par_b = par;
        par_b(Ip.D_diff) = d_4plots(k); %par(Ip.D_diff);
        
        % wild-type readout
        res_wt = spacialwnt_simulation(T, par_b, model);
        mRNA_wt_b = res_wt.states.mRNA;
        
        par_b(Ip.apc_tot(11)) =  par_b(Ip.apc_tot(11))/10;
        
        % mutant readout
        res_mut = spacialwnt_simulation(T, par_b, model);
        mRNA_mut_b = res_mut.states.mRNA;
        
        changeMUT{k} = 100*(mRNA_mut_b-mRNA_wt_b)./mRNA_wt_b;

        
    end

    %% Figure

    figure()
    xSpl = -6:0.01:0;
    splMRNA = spline(log10(D_diff),relMRNA,xSpl);
    semilogx(exp(log(10)*xSpl)*1500,splMRNA,'k')
    title('Rel change in mRNA of PP neighbour of central mutant')
    hold on
    semilogx(d_4plots*1500,spline(log10(D_diff),relMRNA,log10(d_4plots)),'o')
    xlim([min(exp(log(10)*xSpl)*1500) max(exp(log(10)*xSpl)*1500)])

    figure()

    scale_factor = 40;

    subplot(2,2,1)
    change_disp1 = changeMUT{1};
    change_disp1(11)=change_disp1(11)/scale_factor;
    bar(1:21,change_disp1,'k')
    xlim([0.5 21.5])
    ylim([-20 20])
    set(gca,'Xtick',[1.5 20.5])
    set(gca,'XtickLabel',{'PC','PP'})
    title('Much weaker diffusion than reference')

    subplot(2,2,2)
    change_disp2 = changeMUT{2};
    change_disp2(11)=change_disp2(11)/scale_factor;
    bar(1:21,change_disp2,'k')
    xlim([0.5 21.5])
    ylim([-20 20])
    set(gca,'Xtick',[1.5 20.5])
    set(gca,'XtickLabel',{'PC','PP'})
    title('Weaker diffusion than reference')

    subplot(2,2,3)
    change_disp3 = changeMUT{3};
    change_disp3(11)=change_disp3(11)/scale_factor;
    bar(1:21,change_disp3,'k')
    xlim([0.5 21.5])
    ylim([-20 20])
    set(gca,'Xtick',[1.5 20.5])
    set(gca,'XtickLabel',{'PC','PP'})
    title('Reference')

    subplot(2,2,4)
    change_disp4 = changeMUT{4};
    change_disp4(11)=change_disp4(11)/scale_factor;
    bar(1:21,change_disp4,'k')
    xlim([0.5 21.5])
    ylim([-20 20])
    set(gca,'Xtick',[1.5 20.5])
    set(gca,'XtickLabel',{'PC','PP'})
    title('Stronger diffusion than reference')

end

