%FIGS1(PAR, MODEL, T) Creates supplementary figure 1
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = figS1(par, model, T)

    Ip = model.par.Ip;
    
    %% Computation
    
    cmRNA_vec = logspace(0,3,20)/50;
    Dkk_vec = zeros(size(cmRNA_vec));
    TGmRNA_vec = zeros(size(cmRNA_vec));
    
    for i=1:length(cmRNA_vec)
        par_mut = par;

        par_mut(Ip.c_mRNA) = cmRNA_vec(i);
        
        res_mut = spacialwnt_simulation(T, par_mut, model);
        Dkk_vec(i) = res_mut.states.dkk(12);
        TGmRNA_vec(i) = res_mut.states.mRNA(12)/100; %TODO: correction factor Dkk --> TG
    end
    TG_min = 0.041; %TODO: where does this value come from?

    %% Figure
    
    figure()
    
    semilogx(Dkk_vec,TGmRNA_vec,'LineWidth',5)
    hold on
    semilogx(Dkk_vec, repmat(TG_min,size(Dkk_vec)), 'k--','LineWidth',3)
    xlabel('Dkk [nM]')
    ylabel('target gene mRNA [nM]')
    xlim([0.95*min(Dkk_vec) 1.05*max(Dkk_vec)])
    ylim([-0.05*range(TGmRNA_vec) 1.05*max(TGmRNA_vec)])
%    set(gca,'Xtick',1:5)
    title('readout cell')

end

