%FIGS2(PAR, MODEL, T) Creates supplementary figure 2
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = figS2(par, model, T)

    Ip = model.par.Ip;
    
    mutmdl = model;
    mutmdl.mutcells = 11;
    
    %% Computation
    
    RCTGE = zeros(5,1);
    res_wt = spacialwnt_simulation(T, par, model);
    mRNA_wt = res_wt.states.mRNA;

    for i=1:5
        par_mut = par;
        mutmdl.mutcells = (12-i):11;
        par_mut(Ip.apc_tot(mutmdl.mutcells)) = ...
            par_mut(Ip.apc_tot(mutmdl.mutcells))/10;
        
        res_mut = spacialwnt_simulation(T, par_mut, mutmdl);
        mRNA_mut = res_mut.states.mRNA;
        RCTGE(i) = (mRNA_mut(12)-mRNA_wt(12))/mRNA_wt(12);
    end
    
    %% Figure
    
    figure()
    
    plot(1:5,100*RCTGE,'o','LineWidth',5,'MarkerSize',6)
    xlabel('Number of mutant cells')
    ylabel('Rel. change of TG mRNA [%]')
    xlim([0.9 5.1])
    ylim([-30 0])
    set(gca,'Xtick',1:5)
    title('readout cell')

end

