%FIGS3(PAR, MODEL, T) Creates supplementary figure 3
%   
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function [] = figS3(par, model, T)

    Ip = model.par.Ip;
    
    mutmdl = model;
    mutmdl.mutcells = 11;
    
    %% Computation
    
    %for panel A
     factk12_mut = 2.^(0:7);
 
     nsim = length(factk12_mut);
     FC_roc = zeros(nsim,1); %Change of target gene expression in readout cell (nr. 12)
 
     res_wt = spacialwnt_simulation(T, par, model);
     mRNA_wt = res_wt.states.mRNA;
    
    par_a = par;
    par_a(Ip.apc_tot(11)) = par_a(Ip.apc_tot(11))/10;
    for i=1:nsim
        par_a(Ip.fact_cmRNA) = factk12_mut(i);
        
        res_mut = spacialwnt_simulation(T, par_a, mutmdl);
        mRNA_mut = res_mut.states.mRNA;
        FC_roc(i) = (mRNA_mut(12)-mRNA_wt(12))/mRNA_wt(12);
    end
    
    %for panel B:
    par_20 = par_a;
    par_20(Ip.fact_cmRNA) = 1000;
    res20 = spacialwnt_simulation(T, par_20, mutmdl);
    mRNA_20 = res20.states.mRNA;
    
    RCTGE_20 = 100*(mRNA_20-mRNA_wt)./mRNA_wt;
    

    %% Figure
    
    figure()
    
    nrow = 1;
    ncol = 2;
    % panel A:
    subplot(nrow,ncol,1)   

    k12_mut = factk12_mut * par_a(Ip.c_mRNA);
    semilogx(k12_mut, 100*FC_roc,'LineWidth',2)
    hold on
    title('Impact of increased Dkk translation rate in mutant')
    xlabel('k_{12} in mutant')
    ylabel('RC TGE (%)')
    ylim([-70 20])
    xlim([0.018 2.1])
    semilogx(k12_mut(1),100*FC_roc(1),'o')

    % panel B:
    subplot(nrow,ncol,2)   

    SF = 20; %scaling factor for display
    RCTGE_20(11) = RCTGE_20(11)/SF;
    
    bar(1:21,RCTGE_20,'b')
    xlim([0.5 21.5])
    ylim([-70 20])
    set(gca,'Xtick',[1.5 20.5],'XtickLabel',{'PC','PP'})
    title('k_{12}^{mut} = 1000*k_{12}^{wt}')

end

