%X0 = SPACIALWNT_X0(PAR, MODEL) Initial conditions for spacial Wnt model
%   PAR: a parameter vector
%   MODEL: a struct as created by 'spacialwnt_index'
%   
%   X0: the vector of initial conditions
%
%   Manuscript:
%
%  "Paracrine and Autocrine Regulation of Gene Expression by 
%   Wnt-Inhibitor Dickkopf in  Wild-type and Mutant Hepatocytes"
%   by Niklas Hartung, Uwe Benary, Jana Wolf, Bente Kofahl
%
%  code by: Niklas Hartung, University of Potsdam, 2017 
function x0 = spacialwnt_x0(par,model)

    ncell = model.ncell;
    nstate = model.states.nstate;
    Ip = model.par.Ip;
    Ix = model.states.Ix;
    
    x0 = zeros(nstate,ncell);
    
    x0(Ix.apc,:) = par(Ip.apc_tot);
    x0(Ix.tcf,:) = 70*ones(1,ncell); % par(Ip.tcf_tot);
    x0(Ix.dkk,:) = 10*ones(1,ncell); % par(Ip.dkk);
    x0(Ix.bcat,:)    = zeros(1,ncell);
    x0(Ix.bcattcf,:) = zeros(1,ncell);
    x0(Ix.dsh_a,:)   = zeros(1,ncell);
    x0(Ix.mRNA,:)    = zeros(1,ncell);
    x0(Ix.dkklrp,:)  = zeros(1,ncell);
    x0(Ix.wntfrz,:)  = zeros(1,ncell);
    x0(Ix.wntcomp,:) = zeros(1,ncell);
    
    x0 = x0(:);
end

